exec

package
v0.6.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 15, 2013 License: BSD-3-Clause Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateScript

func CreateScript(ctx *env.Context, path *[]string, gemHome string)

CreateScript creates a runner script tuned to the type of shell that called the uru runtime.

func ExecScript

func ExecScript(ctx *env.Context)

ExecScript executes the runner script based upon the type of shell that called the uru runtime.

Types

This section is empty.

Jump to