env

package
v0.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 20, 2013 License: BSD-3-Clause Imports: 14 Imported by: 0

Documentation

Index

Constants

const (
	AppName    = `uru`
	AppVersion = `0.4.0`
)

Variables

var BashWrapper = `` /* 663-byte string literal not displayed */

Functions

func CopyFile

func CopyFile(dst, src string) (written int64, err error)

CopyFile copies a source file to a destination file.

func MarshalRubies

func MarshalRubies(ctx *Context) (err error)

MarshallRubies persists the registered rubies to a JSON formatted file.

func NewTag added in v0.4.0

func NewTag(ctx *Context, rb Ruby) (tag string, err error)

NewTag generates a new tag value used to identify a specific ruby.

func PathListForTag

func PathListForTag(ctx *Context, tag string) (path []string, err error)

PathListForTag returns a PATH list appropriate for a given ruby tag.

func SelectRubyFromList added in v0.4.0

func SelectRubyFromList(tags map[string]Ruby, label, verb string) (tag string, err error)

SelectRubyFromList presents a list of registered rubies and asks the user to select one. It returns the identifying tag for the selected ruby, or an error if unable to get the users selection.

func StringSplitPath

func StringSplitPath() (path []string, err error)

StringSplitPath splits the PATH env var into a slice of strings.

func TagLabelToTag added in v0.4.0

func TagLabelToTag(ctx *Context, label string) (tags map[string]Ruby, err error)

TagLabelToTag returns a map of registered ruby tags whose TagLabel's match that of the specified tag label string.

func UIYesConfirm

func UIYesConfirm(prompt string) (resp string, err error)

UIYesConfirm asks the user a question and returns Y or N with Y being the default.

Types

type Context

type Context struct {
	Rubies RubyRegistry
	// contains filtered or unexported fields
}

func (*Context) Cmd

func (c *Context) Cmd() string

func (*Context) CmdArgs

func (c *Context) CmdArgs() []string

func (*Context) CmdRegex

func (c *Context) CmdRegex(cmd string) *regexp.Regexp

func (*Context) Home

func (c *Context) Home() string

func (*Context) Init

func (c *Context) Init()

func (*Context) SetCmd

func (c *Context) SetCmd(cmd string)

func (*Context) SetCmdAndArgs

func (c *Context) SetCmdAndArgs(cmd string, args []string)

func (*Context) SetCmdArgs

func (c *Context) SetCmdArgs(args []string)

func (*Context) SetCmdRegex

func (c *Context) SetCmdRegex(cmd string, r string) error

func (*Context) SetHome

func (c *Context) SetHome(h string)

type Ruby

type Ruby struct {
	ID          string // ruby version including patch number
	TagLabel    string // user friendly ruby tag value
	Exe         string // ruby executable name
	Home        string // full path to ruby executable directory
	GemHome     string // full path to a ruby's gem home directory
	Description string // full ruby description
}

func CurrentRubyInfo

func CurrentRubyInfo(ctx *Context) (tag string, info Ruby, err error)

CurrentRubyInfo returns the identifying tag and metadata information for the ruby currently in use.

func RubyInfo

func RubyInfo(ctx *Context, ruby string) (tag string, info Ruby, err error)

RubyInfo returns an identifying tag and metadata information about a specific ruby. It accepts a string of either the simple name of the ruby executable, or the ruby executables absolute path.

type RubyRegistry

type RubyRegistry map[string]Ruby

Jump to