Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateScript ¶
CreateScript creates a runner script tuned to the type of shell that called the uru runtime.
func ExecScript ¶
ExecScript executes the runner script based upon the type of shell that called the uru runtime.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.